@@ -11,11 +11,9 @@ import sys
 app_name = get_app_name()
 args = get_args()
 print('test-2')
-args.remove(app_name)
-print('test-3')
-print(args)
 
 def main():
+    print('test-3')
     if (is_name_valid(app_name)):
 
         # validate all arguments first!!
